@@ -436,6 +436,30 @@ class Grainer(AbstractGrainer, CustomEnum):
 
         return _apply_grainer(clip, _noise_function, **kwargs, func=self.name)
 
+    @staticmethod
+    def norm_brightness() -> Callable[[vs.VideoNode], vs.VideoNode]:
+        """
+        Normalize the brightness of the grained clip to match the original clip's average luminance.
+
+        Designed for use in the `post_process` parameter of [Grainer()][vsdeband.Grainer.__call__].
+
+        Returns:
+            A function that takes a grained clip and returns a brightness-normalized version.
+        """
+
+        def _funtion(grained: vs.VideoNode) -> vs.VideoNode:
+            for i in range(grained.format.num_planes):
+                grained = core.std.PlaneStats(grained, plane=i, prop=f"PS{i}")
+
+            if grained.format.sample_type is vs.FLOAT:
+                expr = "x x.PS{plane_idx}Average -"
+            else:
+                expr = "x neutral range_size / x.PS{plane_idx}Average - range_size * +"
+
+            return norm_expr(grained, expr, func=Grainer.norm_brightness)
+
+        return _funtion
+
 
 def _apply_grainer(
     clip: ConstantFormatVideoNode,
