@@ -58,7 +58,31 @@ class dpir(CustomStrEnum):  # noqa: N801
         **kwargs: Any,
     ) -> ConstantFormatVideoNode:
         """
-        Deep Plug-and-Play Image Restoration
+        Deep Plug-and-Play Image Restoration.
+
+        Example:
+            Apply DPIR to an entire clip with a global strength of 15,
+            a strength of 20 in the frame range (10, 20),
+            a strength of 5 in the frame ranges (500, 1000) and (1500, 2500),
+            restricted to the chroma planes only,
+            and using the TRT_RTX backend:
+
+            ```py
+            import vsmlrt
+
+            clip = dpir.DEBLOCK(
+                clip,
+                15,
+                [((10, 20), 20), ([(500, 1000), (1500, 2500)], 5)],
+                planes=[1, 2],
+                backend=vsmlrt.Backend.TRT_RTX,
+            )
+            ```
+
+        Notes:
+            - DPIR requires RGB or GRAY input (automatically upsampled if YUV).
+            - The default chroma upscaler is Catrom.
+              Users may substitute a higher-quality upscaler if needed.
 
         Args:
             clip: Clip to process.
@@ -71,8 +95,8 @@ class dpir(CustomStrEnum):  # noqa: N801
                 If a VideoNode is used, it must be in GRAY8, GRAYH, or GRAYS format,
                 with pixel values representing the 8-bit thresholds.
 
-            zones: Apply different strength in specified zones.
-            **kwargs: Additional arguments to be passed to `vsscale.DPIR`.
+            zones: Apply different strength values to specific frame ranges.
+            **kwargs: Additional arguments to be passed to [vsscale.DPIR][].
         """
         func = "dpir." + str(self.value)
 
@@ -139,7 +163,7 @@ class dpir(CustomStrEnum):  # noqa: N801
             out = dpired
 
         if planes != normalize_planes(clip, None):
-            out = join({None: clip, tuple(planes): dpired}, clip.format.color_family)
+            out = join({None: clip, tuple(planes): dpired}, clip.format.color_family, prop_src=clip)
 
         return out
 
@@ -239,7 +263,7 @@ def deblock_qed(
             deblocked = join(deblocked, strong)
 
     if fieldbased.is_inter:
-        deblocked = weave(Box().scale(deblocked, height=clip.height // 2), fieldbased)
+        deblocked = weave(Box().scale(deblocked, height=clip.height // 2), fieldbased, deblock_qed)
 
     return deblocked
 
@@ -277,10 +301,13 @@ def mpeg2stinx(
         if sw == sh == 1:
             repaired = repair(clip, bobbed, 1)
         else:
-            inpand, expand = Morpho.inpand(bobbed, sw, sh), Morpho.expand(bobbed, sw, sh)
+            inpand, expand = (
+                Morpho.inpand(bobbed, sw, sh, func=mpeg2stinx),
+                Morpho.expand(bobbed, sw, sh, func=mpeg2stinx),
+            )
             repaired = norm_expr([clip, inpand, expand], "x y z clip", func=mpeg2stinx)
 
-        return weave(repaired.std.SeparateFields(tff).std.SelectEvery(4, (2, 1)), tff)
+        return weave(repaired.std.SeparateFields(tff).std.SelectEvery(4, (2, 1)), tff, func=mpeg2stinx)
 
     def _temporal_limit(src: vs.VideoNode, flt: vs.VideoNode, adj: vs.VideoNode | None) -> vs.VideoNode:
         if limit is None:
@@ -289,8 +316,8 @@ def mpeg2stinx(
         assert adj
 
         diff = norm_expr([core.std.Interleave([src, src]), adj], "x y - abs", func=mpeg2stinx).std.SeparateFields(tff)
-        diff = MeanMode.MINIMUM([diff.std.SelectEvery(4, (0, 1)), diff.std.SelectEvery(4, (2, 3))])
-        diff = weave(Morpho.expand(diff, sw=2, sh=1), tff)
+        diff = MeanMode.MINIMUM([diff.std.SelectEvery(4, (0, 1)), diff.std.SelectEvery(4, (2, 3))], func=mpeg2stinx)
+        diff = weave(Morpho.expand(diff, sw=2, sh=1), tff, mpeg2stinx)
 
         return norm_expr([flt, src, diff], "z {limit} * LIM! x y LIM@ - y LIM@ + clip", limit=limit, func=mpeg2stinx)
 
