@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from fractions import Fraction
 from itertools import chain
-from typing import TYPE_CHECKING, Any, Literal, MutableMapping, Union, overload
+from typing import Any, Literal, MutableMapping, Union, overload
 
 from vstools import (
     ColorRange,
@@ -12,7 +12,7 @@ from vstools import (
     InvalidColorFamilyError,
     KwargsNotNone,
     KwargsT,
-    PlanesT,
+    Planes,
     VSFunctionNoArgs,
     check_variable,
     check_variable_format,
@@ -20,7 +20,6 @@ from vstools import (
     depth,
     fallback,
     get_props,
-    normalize_planes,
     normalize_seq,
     scale_delta,
     vs,
@@ -100,7 +99,7 @@ class MVTools(vs_object):
         vectors: MotionVectors | None = None,
         pad: int | tuple[int | None, int | None] | None = None,
         pel: int | None = None,
-        planes: PlanesT = None,
+        chroma: bool | None = None,
         *,
         super_args: KwargsT | None = None,
         analyze_args: KwargsT | None = None,
@@ -137,7 +136,7 @@ class MVTools(vs_object):
             pad: How much padding to add to the source frame. Small padding is added to help with motion estimation near
                 frame borders.
             pel: Subpixel precision for motion estimation (1=pixel, 2=half-pixel, 4=quarter-pixel). Default: 1.
-            planes: Which planes to process. Default: None (all planes).
+            chroma: Whether to consider chroma in motion vector calculations.
             super_args: Arguments passed to every [MVToolsPlugin.Super][vsdenoise.MVToolsPlugin.Super] calls.
             analyze_args: Arguments passed to every [MVToolsPlugin.Analyze][vsdenoise.MVToolsPlugin.Analyze] calls.
             recalculate_args: Arguments passed to every [MVToolsPlugin.Recalculate][vsdenoise.MVToolsPlugin.Recalculate]
@@ -166,13 +165,11 @@ class MVTools(vs_object):
         self.fieldbased = FieldBased.from_video(clip, False, self.__class__)
         self.clip = clip.std.SeparateFields(self.fieldbased.is_tff) if self.fieldbased.is_inter else clip
 
-        self.planes = normalize_planes(self.clip, planes)
-        self.mv_plane = planes_to_mvtools(self.planes)
-        self.chroma = self.mv_plane != 0
-        self.disable_compensate = False
-
         self.pel = pel
         self.pad = normalize_seq(pad, 2)
+        self.chroma = chroma
+
+        self.disable_compensate = False
 
         if callable(search_clip):
             self.search_clip = search_clip(self.clip)
@@ -398,7 +395,7 @@ class MVTools(vs_object):
         )
 
         if self.vectors.has_vectors:
-            self.vectors.clear()
+            self.vectors = MotionVectors()
 
         self.vectors.tr = tr
 
@@ -562,7 +559,8 @@ class MVTools(vs_object):
         time: float | None = None,
         thscd: int | tuple[int | None, int | float | None] | None = None,
         interleave: Literal[True] = True,
-        temporal_func: VSFunctionNoArgs[vs.VideoNode, vs.VideoNode] = ...,
+        *,
+        temporal_func: VSFunctionNoArgs[vs.VideoNode, vs.VideoNode],
     ) -> ConstantFormatVideoNode: ...
 
     @overload
@@ -578,7 +576,8 @@ class MVTools(vs_object):
         thsad2: int | None = None,
         time: float | None = None,
         thscd: int | tuple[int | None, int | float | None] | None = None,
-        interleave: Literal[False] = False,
+        *,
+        interleave: Literal[False],
         temporal_func: None = None,
     ) -> tuple[list[ConstantFormatVideoNode], list[ConstantFormatVideoNode]]: ...
 
@@ -710,7 +709,8 @@ class MVTools(vs_object):
         mode: FlowMode | None = None,
         thscd: int | tuple[int | None, int | float | None] | None = None,
         interleave: Literal[True] = True,
-        temporal_func: VSFunctionNoArgs[vs.VideoNode, vs.VideoNode] = ...,
+        *,
+        temporal_func: VSFunctionNoArgs[vs.VideoNode, vs.VideoNode],
     ) -> ConstantFormatVideoNode: ...
 
     @overload
@@ -724,7 +724,8 @@ class MVTools(vs_object):
         time: float | None = None,
         mode: FlowMode | None = None,
         thscd: int | tuple[int | None, int | float | None] | None = None,
-        interleave: Literal[False] = False,
+        *,
+        interleave: Literal[False],
         temporal_func: None = None,
     ) -> tuple[list[ConstantFormatVideoNode], list[ConstantFormatVideoNode]]: ...
 
@@ -829,6 +830,7 @@ class MVTools(vs_object):
         thsad2: int | tuple[int | None, int | None] | None = None,
         limit: int | tuple[int | None, int | None] | None = None,
         thscd: int | tuple[int | None, int | float | None] | None = None,
+        planes: Planes = None,
     ) -> ConstantFormatVideoNode:
         """
         Perform temporal denoising using motion compensation.
@@ -853,6 +855,7 @@ class MVTools(vs_object):
 
                    - First value: SAD threshold for considering a block changed between frames.
                    - Second value: Percentage of changed blocks needed to trigger a scene change.
+            planes: Which planes to process. Default: None (all planes).
 
         Returns:
             Motion compensated and temporally filtered clip with reduced noise.
@@ -866,7 +869,7 @@ class MVTools(vs_object):
 
         thscd1, thscd2 = normalize_thscd(thscd)
 
-        degrain_args = dict[str, Any](thscd1=thscd1, thscd2=thscd2, plane=self.mv_plane)
+        degrain_args = dict[str, Any](thscd1=thscd1, thscd2=thscd2, plane=planes_to_mvtools(clip, planes))
 
         if self.mvtools is MVToolsPlugin.FLOAT:
             if tr == 1:
@@ -1386,7 +1389,7 @@ class MVTools(vs_object):
         if self.mvtools is MVToolsPlugin.FLOAT:
             return vectors.mv_multi[(delta - 1) * 2 + direction - 1 :: vectors.tr * 2]
 
-        return vectors.motion_vectors[direction][delta]
+        return vectors[direction][delta]
 
     @overload
     def get_vectors(
@@ -1403,7 +1406,8 @@ class MVTools(vs_object):
         vectors: MotionVectors | None = None,
         direction: MVDirection = MVDirection.BOTH,
         tr: int | None = None,
-        multi: Literal[True] = ...,
+        *,
+        multi: Literal[True],
     ) -> ConstantFormatVideoNode: ...
 
     @overload
@@ -1470,13 +1474,9 @@ class MVTools(vs_object):
         return (vectors_backward, vectors_forward)
 
     def __vs_del__(self, core_id: int) -> None:
-        if not TYPE_CHECKING:
-            self.clip = None
+        for k, v in self.__dict__.copy().items():
+            if isinstance(v, vs.VideoNode):
+                delattr(self, k)
 
-        for v in self.__dict__.values():
-            if not isinstance(v, MutableMapping):
-                continue
-
-            for k2, v2 in v.items():
-                if isinstance(v2, vs.VideoNode):
-                    v[k2] = None
+            if isinstance(v, MutableMapping):
+                v.clear()
