@@ -1,9 +1,15 @@
 from __future__ import annotations
 
+import re
+from logging import debug as logging_debug
 from math import ceil
-from typing import TYPE_CHECKING, Any, Iterable, Sequence, SupportsIndex, TypeAlias, Union
+from typing import TYPE_CHECKING, Any, Callable, Iterable, Sequence, SupportsIndex, TypeAlias, Union
+from warnings import warn
+
+from jetpytools import CustomIndexError, norm_func_name
 
 from vstools import (
+    EXPR_VARS,
     ConstantFormatVideoNode,
     CustomRuntimeError,
     FuncExcept,
@@ -18,13 +24,15 @@ from vstools import (
     core,
     flatten_vnodes,
     get_video_format,
+    normalize_planes,
+    normalize_seq,
     to_arr,
     vs,
 )
 
 from .error import CustomExprError
-from .exprop import ExprList, ExprOp, ExprOpBase, TupleExprList
-from .util import ExprVars, bitdepth_aware_tokenize_expr, norm_expr_planes
+from .exprop import ExprList, ExprOp, ExprOpBase, TupleExprList, _TokenDeprecation
+from .util import ExprVars
 
 __all__ = ["combine", "combine_expr", "expr_func", "norm_expr"]
 
@@ -72,6 +80,8 @@ def expr_func(
 
     fmt = get_video_format(format).id if format is not None else None
 
+    logging_debug(f"expr_func ({norm_func_name(func)}): {expr}")
+
     try:
         return core.akarin.Expr(clips, expr, fmt, opt, boundary)
     except AttributeError as e:
@@ -95,7 +105,7 @@ def _combine_norm__ix(ffix: SupportsString | Iterable[SupportsString] | None, n_
 
 
 def combine_expr(
-    n: SupportsIndex | ExprVars | HoldsVideoFormat | VideoFormatLike,
+    n: SupportsIndex | Sequence[SupportsString] | HoldsVideoFormat | VideoFormatLike,
     operator: ExprOpBase = ExprOp.MAX,
     suffix: SupportsString | Iterable[SupportsString] | None = None,
     prefix: SupportsString | Iterable[SupportsString] | None = None,
@@ -108,7 +118,7 @@ def combine_expr(
     For combining multiple clips, see [combine][vsexprtools.combine].
 
     Args:
-        n: Object from which to infer the number of variables.
+        n: Object from which to infer the variables.
         operator: An ExprOpBase enum used to join the variables.
         suffix: Optional suffix string(s) to append to each input variable in the expression.
         prefix: Optional prefix string(s) to prepend to each input variable in the expression.
@@ -118,8 +128,8 @@ def combine_expr(
     Returns:
         A expression representing the combined result.
     """
-    evars = ExprVars(n)
-    n = evars.stop - evars.start
+    evars = n if isinstance(n, Sequence) else ExprVars(n)
+    n = len(evars)
 
     prefixes, suffixes = (_combine_norm__ix(x, n) for x in (prefix, suffix))
 
@@ -193,7 +203,7 @@ def norm_expr(
 ) -> ConstantFormatVideoNode:
     """
     Evaluate a per-pixel expression on input clip(s), normalize it based on the specified planes,
-    and format tokens and placeholders using provided keyword arguments.
+    and format [tokens][vsexprtools.ExprToken] and placeholders using provided keyword arguments.
 
     Web app to dissect expressions:
         - <https://jaded-encoding-thaumaturgy.github.io/expr101/>
@@ -256,3 +266,82 @@ def norm_expr(
         print(tokenized_expr)
 
     return expr_func(clips, tokenized_expr, format, opt, boundary, func)
+
+
+def extra_op_tokenize_expr(expr: str) -> str:
+    # Workaround for the not implemented op
+    def _replace_polyval(matched: re.Match[str]) -> str:
+        degree = int(matched.group(1))
+        return ExprOp.POLYVAL.convert_extra(degree)
+
+    for extra_op in ExprOp._extra_op_names_:
+        if extra_op.lower() in expr:
+            if extra_op == ExprOp.POLYVAL.name:
+                expr = re.sub(rf"\b{extra_op.lower()}(\d+)\b", _replace_polyval, expr)
+            else:
+                expr = re.sub(rf"\b{extra_op.lower()}\b", getattr(ExprOp, extra_op).convert_extra(), expr)
+
+    return expr
+
+
+def bitdepth_aware_tokenize_expr(
+    clips: Sequence[vs.VideoNode], expr: str, chroma: bool, func: FuncExcept | None = None
+) -> str:
+    from .exprop import ExprToken
+
+    func = func or bitdepth_aware_tokenize_expr
+
+    expr = extra_op_tokenize_expr(expr)
+
+    if not expr or len(expr) < 4:
+        return expr
+
+    replaces = list[tuple[str, Callable[[vs.VideoNode, bool, vs.VideoNode], float]]]()
+
+    for token in sorted(ExprToken, key=lambda x: len(x), reverse=True):
+        if token.value in expr:
+            replaces.append((token.value, token.get_value))
+
+        if token.name in expr:
+            warn(
+                f"Using token name '{token.name}' in expressions is deprecated. "
+                "Use the token's string representation or its value instead.",
+                _TokenDeprecation,
+            )
+            replaces.append((f"{token.__class__.__name__}.{token.name}", token.get_value))
+
+    if not replaces:
+        return expr
+
+    clips = list(clips)
+    mapped_clips = list(reversed(list(zip(["", *EXPR_VARS], clips[:1] + clips))))
+
+    for mkey, function in replaces:
+        if mkey in expr:
+            for key, clip in [(f"{mkey}_{k}" if k else f"{mkey}", clip) for k, clip in mapped_clips]:
+                expr = re.sub(rf"\b{key}\b", str(function(clip, chroma, clip)), expr)
+
+        if re.search(rf"\b{mkey}\b", expr):
+            raise CustomIndexError("Parsing error or not enough clips passed!", func, reason=expr)
+
+    return expr
+
+
+def norm_expr_planes(
+    clip: vs.VideoNode,
+    expr: str | list[str],
+    planes: Planes = None,
+    **kwargs: Iterable[SupportsString] | SupportsString,
+) -> list[str]:
+    assert clip.format
+
+    expr_array = normalize_seq(expr, clip.format.num_planes)
+
+    planes = normalize_planes(clip, planes)
+
+    string_args = [(key, normalize_seq(value)) for key, value in kwargs.items()]
+
+    return [
+        exp.format(**({"plane_idx": i} | {key: value[i] for key, value in string_args})) if i in planes else ""
+        for i, exp in enumerate(expr_array)
+    ]
