@@ -8,11 +8,11 @@ import math
 from abc import ABC
 from typing import Any, ClassVar, Sequence
 
-from jetpytools import interleave_arr
+from jetpytools import interleave_arr, to_arr
 from typing_extensions import deprecated
 
 from vsexprtools import ExprList, ExprOp, norm_expr
-from vstools import ConstantFormatVideoNode, Planes, get_depth, join, split, vs
+from vstools import ConstantFormatVideoNode, Planes, join, split, vs
 
 from ..morpho import Morpho
 from ..types import XxpandMode
@@ -41,8 +41,6 @@ __all__ = [
     "Laplacian4",
     "Kayyali",
     # Euclidean Distance
-    "Tritical",
-    "TriticalTCanny",
     "Cross",
     "Prewitt",
     "PrewittStd",
@@ -117,29 +115,6 @@ class Kayyali(SingleMatrix, Matrix3x3):
 
 
 # Euclidean Distance
-class Tritical(EdgeMasksEdgeDetect, RidgeDetect, EuclideanDistance, Matrix3x3):
-    """
-    Operator used in Tritical's original TCanny filter.
-    Plain and simple orthogonal first order derivative.
-    """
-
-    matrices: ClassVar[Sequence[Sequence[float]]] = [[0, 0, 0, -1, 0, 1, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, -1, 0]]
-
-
-@deprecated(
-    "TriticalTCanny is deprecated and will be removed in a future version. "
-    "Please use Tritical and install the 'edgemasks' plugin instead.",
-    category=DeprecationWarning,
-)
-class TriticalTCanny(TCannyEdgeDetect, Matrix3x3):
-    """
-    Operator used in Tritical's original TCanny filter.
-    Plain and simple orthogonal first order derivative.
-    """
-
-    _op = 0
-
-
 class Cross(EdgeMasksEdgeDetect, RidgeDetect, EuclideanDistance, Matrix3x3):
     """
     "HotDoG" Operator from AVS ExTools by Dogway.
@@ -242,11 +217,36 @@ class SobelTCanny(TCannyEdgeDetect, Matrix3x3):
 
 class ASobel(Matrix3x3, EdgeDetect):
     """
-    Modified Sobel-Feldman operator from AWarpSharp.
+    ASobel from the `AWarpSharp2` VapourSynth plugin.
     """
 
-    def _compute_edge_mask(self, clip: ConstantFormatVideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
-        return (vs.core.warp.ASobel if get_depth(clip) < 32 else vs.core.warpsf.ASobel)(clip, 255, **kwargs)
+    def _compute_edge_mask(
+        self,
+        clip: vs.VideoNode,
+        *,
+        multi: float | Sequence[float] = 1.0,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
+        expr = (
+            "x[-1,-1] x[1,-1] + 2 / x[0,-1] + 2 / AVG_UP!",
+            "x[-1,1] x[1,1] + 2 / x[0,1] + 2 / AVG_DOWN!",
+            "x[-1,-1] x[-1,1] + 2 / x[-1,0] + 2 / AVG_LEFT!",
+            "x[1,-1] x[1,1] + 2 / x[1,0] + 2 / AVG_RIGHT!",
+            "AVG_UP@ AVG_DOWN@ - abs DIFF_V!",
+            "AVG_LEFT@ AVG_RIGHT@ - abs DIFF_H!",
+            "DIFF_V@ DIFF_H@ + mask_max min DIFF_V@ DIFF_H@ max + mask_max min A!",
+            "A@ 2 * mask_max min A@ + mask_max min 2 * mask_max min",
+        )
+
+        return norm_expr(
+            clip,
+            [expr, "{multi}"],
+            planes,
+            func=self.__class__,
+            multi=[f"{m} *" if m != 1.0 else "" for m in to_arr(multi)],
+            **kwargs,
+        )
 
 
 class Scharr(EdgeMasksEdgeDetect, RidgeDetect, EuclideanDistance, Matrix3x3):
@@ -444,13 +444,21 @@ class MinMax(EdgeDetect):
         self.radc = radc
         super().__init__(**kwargs)
 
-    def _compute_edge_mask(self, clip: ConstantFormatVideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
+    def _compute_edge_mask(
+        self,
+        clip: ConstantFormatVideoNode,
+        *,
+        multi: float | Sequence[float] = 1.0,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
         return join(
             [
                 ExprOp.SUB.combine(
                     Morpho.expand(p, rad, rad, XxpandMode.ELLIPSE, **kwargs),
                     Morpho.inpand(p, rad, rad, XxpandMode.ELLIPSE, **kwargs),
-                    planes=kwargs.get("planes"),
+                    expr_suffix=[f"{m} *" if m != 1.0 else "" for m in to_arr(multi)],
+                    planes=planes,
                     func=self.__class__,
                 )
                 if rad > 0
