@@ -1,34 +1,33 @@
+"""
+This module defines core abstract classes for building edge detection and ridge detection operators.
+"""
+
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
 from enum import IntFlag, auto
 from inspect import isabstract
-from typing import Any, ClassVar, Sequence, TypeAlias, TypeVar
+from typing import TYPE_CHECKING, Any, ClassVar, Sequence, TypeAlias, TypeVar
 
-from jetpytools import inject_kwargs_params
+from jetpytools import inject_kwargs_params, to_arr
 from typing_extensions import Self
 
-from vsexprtools import ExprOp, ExprToken, norm_expr
-from vsrgtools import BlurMatrix
+from vsexprtools import ExprList, ExprOp, norm_expr
 from vstools import (
     ColorRange,
     ConstantFormatVideoNode,
     ConvMode,
     FuncExcept,
-    HoldsVideoFormat,
-    KwargsT,
     Planes,
     T,
-    VideoFormatLike,
     check_variable,
+    core,
     depth,
-    get_lowest_value,
     get_peak_value,
     get_subclasses,
     get_video_format,
     inject_self,
     join,
-    limiter,
     normalize_planes,
     scale_mask,
     vs,
@@ -40,8 +39,10 @@ __all__ = [
     "EdgeDetect",
     "EdgeDetectLike",
     "EdgeDetectT",
+    "EdgeMasksEdgeDetect",
     "EuclideanDistance",
     "MagDirection",
+    "MagnitudeEdgeMasks",
     "MagnitudeMatrix",
     "MatrixEdgeDetect",
     "Max",
@@ -56,7 +57,10 @@ __all__ = [
 
 class MagDirection(IntFlag):
     """
-    Direction of magnitude calculation.
+    Direction flags for magnitude calculations.
+
+    Includes 8 primary compass directions (N, NE, E, SE, S, SW, W, NW) and composite groups (e.g., ALL, AXIS, CORNERS).
+    Supports bitwise operations.
     """
 
     N = auto()
@@ -69,16 +73,36 @@ class MagDirection(IntFlag):
     NE = auto()
 
     ALL = N | NW | W | SW | S | SE | E | NE
+    """All eight directions combined."""
 
     AXIS = N | W | S | E
+    """The four cardinal directions: North, West, South, East."""
+
     CORNERS = NW | SW | SE | NE
+    """The four intercardinal (diagonal) directions."""
 
     NORTH = N | NW | NE
+    """All northern directions (North, Northwest, Northeast)."""
+
     WEST = W | NW | SW
+    """All western directions (West, Northwest, Southwest)."""
+
     EAST = E | NE | SE
+    """All eastern directions (East, Northeast, Southeast)."""
+
     SOUTH = S | SW | SE
+    """All southern directions (South, Southwest, Southeast)."""
 
     def select_matrices(self, matrices: Sequence[T]) -> Sequence[T]:
+        """
+        Return matrices matching the active directions in `self`.
+
+        Args:
+            matrices: One item for each primary direction, in definition order.
+
+        Returns:
+            The subset of matrices for directions enabled in `self`.
+        """
         # In Python <3.11, composite flags are included in MagDirection's
         # collection and iteration interfaces.
         primary_flags = [flag for flag in MagDirection if flag != 0 and flag & (flag - 1) == 0]
@@ -129,17 +153,22 @@ def _base_ensure_obj(
 
 class EdgeDetect(ABC):
     """
-    Abstract edge detection interface.
+    Abstract base class for edge detection operators.
     """
 
     _err_class: ClassVar[type[_UnknownMaskDetectError]] = UnknownEdgeDetectError
     """Custom error class used for validation failures."""
 
-    kwargs: KwargsT | None = None
+    kwargs: dict[str, Any]
+    """Arguments passed to the edgemask function(s)."""
 
     def __init__(self, **kwargs: Any) -> None:
-        super().__init__()
+        """
+        Initialize the scaler with optional keyword arguments.
 
+        Args:
+            **kwargs: Keyword arguments passed to the edgemask function(s).
+        """
         self.kwargs = kwargs
 
     @inject_self
@@ -147,15 +176,16 @@ class EdgeDetect(ABC):
     def edgemask(
         self,
         clip: vs.VideoNode,
-        lthr: float = 0.0,
-        hthr: float | None = None,
-        multi: float = 1.0,
+        lthr: float | Sequence[float] | None = None,
+        hthr: float | Sequence[float] | None = None,
+        multi: float | Sequence[float] = 1.0,
         clamp: bool | tuple[float, float] | list[tuple[float, float]] = False,
         planes: Planes = None,
         **kwargs: Any,
     ) -> ConstantFormatVideoNode:
         """
         Makes edge mask based on convolution kernel.
+
         The resulting mask can be thresholded with lthr, hthr and multiplied with multi.
 
         Args:
@@ -171,116 +201,195 @@ class EdgeDetect(ABC):
         """
         assert check_variable(clip, self.__class__)
 
-        clip_p = self._preprocess(clip)
+        clip_p = self._preprocess(clip, **kwargs)
 
-        mask = self._compute_edge_mask(clip_p, planes=planes, **kwargs)
+        mask = self._compute_edge_mask(clip_p, multi=multi, planes=planes, **kwargs)
 
         mask = self._postprocess(mask, clip)
 
-        return self._finalize_mask(mask, lthr, hthr, multi, clamp, planes)
+        return self._finalize_mask(mask, lthr, hthr, clamp, planes)
 
     @classmethod
-    def depth_scale(
-        cls, clip: vs.VideoNode, bitdepth: VideoFormatLike | HoldsVideoFormat | int
-    ) -> ConstantFormatVideoNode:
+    def _depth_scale(cls, clip: vs.VideoNode, bitdepth: vs.VideoNode) -> ConstantFormatVideoNode:
         assert check_variable(clip, cls)
 
         fmt = get_video_format(bitdepth)
 
         if fmt.sample_type == vs.INTEGER:
-            return norm_expr(
-                clip,
-                ("x abs {peak} *", "x abs {peak} * neutral -"),
-                format=fmt,
-                peak=get_peak_value(bitdepth),
-            )
+            return norm_expr([clip, bitdepth], "x mask_max_y *", format=fmt, func=cls)
         return clip
 
     @classmethod
     def from_param(
         cls, value: type[Self] | Self | str | None = None, /, func_except: FuncExcept | None = None
     ) -> type[Self]:
+        """
+        Resolve and return an edgemask type from a given input (string, type, or instance).
+
+        Args:
+            value: Edgemask identifier (string, class, or instance).
+            func_except: Function returned for custom error handling.
+
+        Returns:
+            Resolved edgemask type.
+        """
         return _base_from_param(cls, value, cls._err_class, func_except)
 
     @classmethod
     def ensure_obj(cls, value: type[Self] | Self | str | None = None, /, func_except: FuncExcept | None = None) -> Self:
+        """
+        Ensure that the input is an edgemask instance, resolving it if necessary.
+
+        Args:
+            value: Edgemask identifier (string, class, or instance).
+            func_except: Function returned for custom error handling.
+
+        Returns:
+            Edgemask instance.
+        """
         return _base_ensure_obj(cls, value, func_except)
 
     def _finalize_mask(
         self,
         mask: ConstantFormatVideoNode,
-        lthr: float,
-        hthr: float | None,
-        multi: float,
+        lthr: float | Sequence[float] | None,
+        hthr: float | Sequence[float] | None,
         clamp: bool | tuple[float, float] | list[tuple[float, float]],
         planes: Planes,
     ) -> ConstantFormatVideoNode:
-        peak = get_peak_value(mask)
+        if not any([lthr, hthr, clamp]):
+            planes = normalize_planes(mask, planes)
 
-        hthr = 1.0 if hthr is None else hthr
+            if planes == normalize_planes(mask, None):
+                return mask
 
-        lthr = scale_mask(lthr, 32, mask)
-        hthr = scale_mask(hthr, 32, mask)
+            return join({None: mask.std.BlankClip(color=[0] * mask.format.num_planes, keep=True), tuple(planes): mask})
 
-        if multi != 1:
-            mask = ExprOp.MUL(mask, suffix=str(multi), planes=planes)
+        if lthr is None:
+            lthr = 0.0
+        if hthr is None:
+            hthr = 1.0
+
+        lthr = [scale_mask(lt, 32, mask) for lt in to_arr(lthr)]
+        hthr = [scale_mask(ht, 32, mask) for ht in to_arr(hthr)]
+
+        peak = get_peak_value(mask, range_in=ColorRange.FULL)
+
+        thr_expr = ExprList(["x"])
 
         if lthr == hthr:
-            mask = norm_expr(mask, f"x {hthr} >= {ExprToken.RangeMax} 0 ?", planes, func=self.__class__)
-        elif lthr > 0 and hthr < peak:
-            mask = norm_expr(mask, f"x {hthr} > {ExprToken.RangeMax} x {lthr} < 0 x ? ?", planes, func=self.__class__)
-        elif lthr > 0:
-            mask = norm_expr(mask, f"x {lthr} < 0 x ?", planes, func=self.__class__)
-        elif hthr < peak:
-            mask = norm_expr(mask, f"x {hthr} > {ExprToken.RangeMax} x ?", planes, func=self.__class__)
+            thr_expr.append("{hthr} >= range_max 0 ?")
+        elif any(lt > 0 for lt in lthr) and any(ht < peak for ht in hthr):
+            thr_expr.append("{hthr} >", "range_max", ["x {lthr} < 0 x ?"], "?")
+        elif any(lt > 0 for lt in lthr):
+            thr_expr.append("{lthr} < 0 x ?")
+        elif any(ht < peak for ht in hthr):
+            thr_expr.append("{hthr} > range_max x ?")
 
-        if clamp is True:
-            clamp = (get_lowest_value(mask, range_in=ColorRange.FULL), get_peak_value(mask, range_in=ColorRange.FULL))
-
-        if isinstance(clamp, list):
-            mask = limiter(mask, *zip(*clamp), planes=planes, func=self.__class__)
+        if clamp is True and mask.format.sample_type == vs.FLOAT:
+            clamp = [(0, 1)]
+        elif isinstance(clamp, bool):
+            clamp = [(False, False)]
         elif isinstance(clamp, tuple):
-            mask = limiter(mask, *clamp, planes=planes, func=self.__class__)
+            clamp = [clamp]
 
-        if planes is not None:
-            return join(
-                {
-                    None: mask.std.BlankClip(color=[0] * mask.format.num_planes, keep=True),
-                    tuple(normalize_planes(mask, planes)): mask,
-                }
-            )
+        mask = norm_expr(
+            mask,
+            [thr_expr, "{clamp}"],
+            planes,
+            func=self.__class__,
+            lthr=lthr,
+            hthr=hthr,
+            clamp=["%s %s clamp" % c if any(c) else "" for c in clamp],
+        )
 
-        return mask
+        return self._finalize_mask(mask, None, None, False, planes)
 
     @abstractmethod
-    def _compute_edge_mask(self, clip: ConstantFormatVideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
-        raise NotImplementedError
+    def _compute_edge_mask(
+        self,
+        clip: ConstantFormatVideoNode,
+        *,
+        multi: float | Sequence[float] = 1.0,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode: ...
 
-    def _preprocess(self, clip: ConstantFormatVideoNode) -> ConstantFormatVideoNode:
+    def _preprocess(self, clip: ConstantFormatVideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
         return ColorRange.FULL.apply(clip)
 
-    def _postprocess(
-        self, clip: ConstantFormatVideoNode, input_bits: HoldsVideoFormat | VideoFormatLike | int
-    ) -> ConstantFormatVideoNode:
+    def _postprocess(self, clip: ConstantFormatVideoNode, input_bits: vs.VideoNode) -> ConstantFormatVideoNode:
         return clip
 
 
-class MatrixEdgeDetect(EdgeDetect):
-    matrices: ClassVar[Sequence[Sequence[float]]]
-    divisors: ClassVar[Sequence[float] | None] = None
-    mode_types: ClassVar[Sequence[str] | None] = None
+class TCannyEdgeDetect(EdgeDetect):
+    """
+    Edge detection using VapourSynth's `tcanny` plugin.
+    """
 
-    def _compute_edge_mask(self, clip: ConstantFormatVideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
-        return self._merge_edge(
-            [
-                BlurMatrix.custom(mat, ConvMode(mode))(clip, divisor=div, saturate=False, func=self.__class__, **kwargs)
-                for mat, div, mode in zip(self._get_matrices(), self._get_divisors(), self._get_mode_types())
-            ]
+    _op: ClassVar[int]
+    _scale: ClassVar[float] = 1.0
+
+    def _compute_edge_mask(
+        self,
+        clip: ConstantFormatVideoNode,
+        *,
+        multi: float | Sequence[float] = 1.0,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
+        tcanny_args = {"op": self._op, "planes": planes} | {"sigma": 0, "mode": 1} | kwargs
+
+        if not isinstance(multi, Sequence):
+            return clip.tcanny.TCanny(scale=self._scale * multi, **tcanny_args)
+
+        return norm_expr(
+            clip.tcanny.TCanny(scale=self._scale, **tcanny_args),
+            "x {multi} *",
+            planes,
+            func=self.__class__,
+            multi=[self._scale * m for m in multi],
         )
 
+
+class MatrixEdgeDetect(EdgeDetect):
+    """
+    Edge detection based on convolution matrices.
+    """
+
+    matrices: ClassVar[Sequence[Sequence[float]]]
+    """Convolution kernels used for edge detection."""
+
+    divisors: ClassVar[Sequence[float] | None] = None
+    """Optional divisors applied to each kernel. Defaults to zeros (no division)."""
+
+    mode_types: ClassVar[Sequence[str] | None] = None
+    """Optional convolution modes (e.g. 's' for square). Defaults to 's'."""
+
+    def _compute_edge_mask(
+        self,
+        clip: ConstantFormatVideoNode,
+        *,
+        multi: float | Sequence[float] = 1.0,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
+        exprs = [
+            ExprOp.convolution("x", mat, divisor=div, saturate=False, mode=ConvMode(mode))[0]
+            for mat, div, mode in zip(self._get_matrices(), self._get_divisors(), self._get_mode_types())
+        ]
+        return self._merge_edge(exprs, clip, multi=multi, planes=planes, **kwargs)
+
     @abstractmethod
-    def _merge_edge(self, clips: Sequence[ConstantFormatVideoNode], **kwargs: Any) -> ConstantFormatVideoNode:
-        raise NotImplementedError
+    def _merge_edge(
+        self,
+        exprs: Sequence[ExprList],
+        clip: vs.VideoNode,
+        *,
+        multi: float | Sequence[float] = 1.0,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode: ...
 
     def _get_matrices(self) -> Sequence[Sequence[float]]:
         return self.matrices
@@ -292,18 +401,74 @@ class MatrixEdgeDetect(EdgeDetect):
         return self.mode_types if self.mode_types else ["s"] * len(self._get_matrices())
 
 
+class EdgeMasksEdgeDetect(MatrixEdgeDetect):
+    """
+    Edge detection using VapourSynth's `EdgeMasks` plugin with expression-based convolution fallback.
+    """
+
+    @inject_self
+    @inject_kwargs_params
+    def edgemask(
+        self,
+        clip: vs.VideoNode,
+        lthr: float | Sequence[float] | None = None,
+        hthr: float | Sequence[float] | None = None,
+        multi: float | Sequence[float] = 1.0,
+        clamp: bool | tuple[float, float] | list[tuple[float, float]] = False,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
+        if not hasattr(core, "edgemasks"):
+            kwargs.setdefault("use_expr", True)
+
+        return super().edgemask(clip, lthr, hthr, multi, clamp, planes, **kwargs)
+
+    def _preprocess(self, clip: ConstantFormatVideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
+        if kwargs.get("use_expr"):
+            return super()._preprocess(clip)
+        return clip
+
+    def _compute_edge_mask(
+        self,
+        clip: ConstantFormatVideoNode,
+        *,
+        multi: float | Sequence[float] = 1.0,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
+        if kwargs.pop("use_expr", False):
+            return super()._compute_edge_mask(clip, multi=multi, planes=planes, **kwargs)
+
+        return getattr(core.edgemasks, self.__class__.__name__)(clip, planes, multi, **kwargs)
+
+
 class NormalizeProcessor(MatrixEdgeDetect):
-    def _preprocess(self, clip: ConstantFormatVideoNode) -> ConstantFormatVideoNode:
+    """
+    Edge detection processor with normalized precision.
+    """
+
+    def _preprocess(self, clip: ConstantFormatVideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
         return super()._preprocess(depth(clip, 32))
 
-    def _postprocess(
-        self, clip: ConstantFormatVideoNode, input_bits: HoldsVideoFormat | VideoFormatLike | int
-    ) -> ConstantFormatVideoNode:
-        return super()._postprocess(self.depth_scale(clip, input_bits), input_bits)
+    def _postprocess(self, clip: ConstantFormatVideoNode, input_bits: vs.VideoNode) -> ConstantFormatVideoNode:
+        return super()._postprocess(self._depth_scale(clip, input_bits), input_bits)
 
 
 class MagnitudeMatrix(MatrixEdgeDetect):
+    """
+    Edge detector using a subset of convolution matrices.
+
+    Allows selecting which matrices to apply based on directional flags. By default, all directions are used.
+    """
+
     def __init__(self, mag_directions: MagDirection = MagDirection.ALL, **kwargs: Any) -> None:
+        """
+        Initialize with a set of magnitude directions.
+
+        Args:
+            mag_directions: Directional flags controlling which matrices are used. Defaults to all directions.
+            **kwargs: Additional parameters passed to the base class.
+        """
         super().__init__(**kwargs)
 
         self.mag_directions = mag_directions
@@ -312,31 +477,135 @@ class MagnitudeMatrix(MatrixEdgeDetect):
         return [m for m in self.mag_directions.select_matrices(self.matrices) if m]
 
 
+class MagnitudeEdgeMasks(EdgeMasksEdgeDetect, MagnitudeMatrix):
+    """
+    Edge detector using a subset of convolution matrices.
+
+    Allows selecting which matrices to apply based on directional flags. By default, all directions are used.
+
+    If a subset of directions is selected, the computation automatically switches to the expression-based backend.
+    """
+
+    if TYPE_CHECKING:
+
+        def __init__(self, mag_directions: MagDirection = MagDirection.ALL, **kwargs: Any) -> None:
+            """
+            Initialize the MagnitudeEdgeMasks detector.
+
+            Args:
+                mag_directions: Directional flags controlling which matrices are used. Defaults to all directions.
+                    If a subset is specified, the expression-based backend is used automatically
+                    to support custom directions.
+                **kwargs: Additional parameters forwarded to the base EdgeMasksEdgeDetect class.
+            """
+            ...
+
+    @inject_self
+    @inject_kwargs_params
+    def edgemask(
+        self,
+        clip: vs.VideoNode,
+        lthr: float | Sequence[float] | None = None,
+        hthr: float | Sequence[float] | None = None,
+        multi: float | Sequence[float] = 1.0,
+        clamp: bool | tuple[float, float] | list[tuple[float, float]] = False,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
+        if self.mag_directions != MagDirection.ALL:
+            kwargs["use_expr"] = True
+
+        return super().edgemask(clip, lthr, hthr, multi, clamp, planes, **kwargs)
+
+
 class SingleMatrix(MatrixEdgeDetect, ABC):
-    def _merge_edge(self, clips: Sequence[ConstantFormatVideoNode], **kwargs: Any) -> ConstantFormatVideoNode:
-        return clips[0]
+    """
+    Edge detector that uses a single convolution matrix.
+    """
+
+    def _merge_edge(
+        self,
+        exprs: Sequence[ExprList],
+        clip: vs.VideoNode,
+        *,
+        multi: float | Sequence[float] = 1.0,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
+        return norm_expr(
+            clip,
+            [exprs[0], "{multi}"],
+            planes,
+            func=self.__class__,
+            multi=[f"{m} *" if m != 1.0 else "" for m in to_arr(multi)],
+            **kwargs,
+        )
 
 
 class EuclideanDistance(MatrixEdgeDetect, ABC):
-    def _merge_edge(self, clips: Sequence[ConstantFormatVideoNode], **kwargs: Any) -> ConstantFormatVideoNode:
-        return norm_expr(clips, "x dup * y dup * + sqrt 0 mask_max clamp", kwargs.get("planes"), func=self.__class__)
+    """
+    Edge detector combining two matrices via Euclidean distance.
+    """
+
+    def _merge_edge(
+        self,
+        exprs: Sequence[ExprList],
+        clip: vs.VideoNode,
+        *,
+        multi: float | Sequence[float] = 1.0,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
+        return norm_expr(
+            clip,
+            [exprs[0], "dup *", exprs[1], "dup * + sqrt 0 max", "{multi}"],
+            planes,
+            func=self.__class__,
+            multi=[f"{m} *" if m != 1.0 else "" for m in to_arr(multi)],
+            **kwargs,
+        )
 
 
 class Max(MatrixEdgeDetect, ABC):
-    def _merge_edge(self, clips: Sequence[ConstantFormatVideoNode], **kwargs: Any) -> ConstantFormatVideoNode:
-        return ExprOp.MAX.combine(*clips, planes=kwargs.get("planes"), func=self.__class__)
+    """
+    Edge detector combining multiple matrices by maximum response.
+
+    Produces the edge mask by selecting the maximum value across all convolution results.
+    """
+
+    def _merge_edge(
+        self,
+        exprs: Sequence[ExprList],
+        clip: vs.VideoNode,
+        *,
+        multi: float | Sequence[float] = 1.0,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
+        return norm_expr(
+            clip,
+            [*exprs, ExprOp.MAX * (len(exprs) - 1), "{multi}"],
+            planes,
+            func=self.__class__,
+            multi=[f"{m} *" if m != 1.0 else "" for m in to_arr(multi)],
+        )
 
 
 class RidgeDetect(MatrixEdgeDetect):
+    """
+    Edge detector specialized for ridge detection.
+    """
+
     _err_class: ClassVar[type[_UnknownMaskDetectError]] = UnknownRidgeDetectError
 
     @inject_self
+    @inject_kwargs_params
     def ridgemask(
         self,
         clip: vs.VideoNode,
-        lthr: float = 0.0,
-        hthr: float | None = None,
-        multi: float = 1.0,
+        lthr: float | Sequence[float] | None = None,
+        hthr: float | Sequence[float] | None = None,
+        multi: float | Sequence[float] = 1.0,
         clamp: bool | tuple[float, float] | list[tuple[float, float]] = False,
         planes: Planes = None,
         **kwargs: Any,
@@ -363,45 +632,65 @@ class RidgeDetect(MatrixEdgeDetect):
 
         clip_p = self._preprocess_ridge(clip)
 
-        mask = self._compute_ridge_mask(clip_p, planes=planes, **kwargs)
+        mask = self._compute_ridge_mask(clip_p, multi=multi, planes=planes, **kwargs)
 
         mask = self._postprocess_ridge(mask, clip)
 
-        return self._finalize_mask(mask, lthr, hthr, multi, clamp, planes)
+        return self._finalize_mask(mask, lthr, hthr, clamp, planes)
 
-    def _compute_ridge_mask(self, clip: ConstantFormatVideoNode, **kwargs: Any) -> ConstantFormatVideoNode:
+    def _compute_ridge_mask(
+        self,
+        clip: ConstantFormatVideoNode,
+        *,
+        multi: float | Sequence[float] = 1.0,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
         def _x(c: ConstantFormatVideoNode) -> ConstantFormatVideoNode:
-            return c.std.Convolution(
-                matrix=self._get_matrices()[0], divisor=self._get_divisors()[0], planes=kwargs.get("planes")
-            )
+            return c.std.Convolution(matrix=self._get_matrices()[0], divisor=self._get_divisors()[0], planes=planes)
 
         def _y(c: ConstantFormatVideoNode) -> ConstantFormatVideoNode:
-            return c.std.Convolution(
-                matrix=self._get_matrices()[1], divisor=self._get_divisors()[1], planes=kwargs.get("planes")
-            )
+            return c.std.Convolution(matrix=self._get_matrices()[1], divisor=self._get_divisors()[1], planes=planes)
 
-        x = _x(clip)
-        y = _y(clip)
-        xx = _x(x)
-        yy = _y(y)
-        xy = _y(x)
-        return self._merge_ridge([xx, yy, xy])
+        return self._merge_ridge([_x(clip), _y(clip)], multi=multi, planes=planes, **kwargs)
+
+    def _merge_ridge(
+        self,
+        clips: Sequence[ConstantFormatVideoNode],
+        *,
+        multi: float | Sequence[float] = 1.0,
+        planes: Planes = None,
+        **kwargs: Any,
+    ) -> ConstantFormatVideoNode:
+        (xx,) = ExprOp.convolution("x", self._get_matrices()[0], divisor=self._get_divisors()[0], mode=ConvMode.SQUARE)
+        (yy,) = ExprOp.convolution("y", self._get_matrices()[1], divisor=self._get_divisors()[1], mode=ConvMode.SQUARE)
+        (xy,) = ExprOp.convolution("x", self._get_matrices()[1], divisor=self._get_divisors()[1], mode=ConvMode.SQUARE)
+
+        expr = [
+            xx,
+            "XX!",
+            yy,
+            "YY!",
+            xy,
+            "XY!",
+            "XX@ dup * XY@ dup * 4 * + XX@ YY@ * 2 * - YY@ dup * + sqrt XX@ YY@ + + 0.5 *",
+            "{multi}",
+        ]
 
-    def _merge_ridge(self, clips: Sequence[ConstantFormatVideoNode], **kwargs: Any) -> ConstantFormatVideoNode:
         return norm_expr(
             clips,
-            "x dup * z dup * 4 * + x y * 2 * - y dup * + sqrt x y + + 0.5 *",
-            kwargs.get("planes"),
+            expr,
+            planes,
             func=self.__class__,
+            multi=[f"{m} *" if m != 1.0 else "" for m in to_arr(multi)],
+            **kwargs,
         )
 
     def _preprocess_ridge(self, clip: ConstantFormatVideoNode) -> ConstantFormatVideoNode:
         return depth(super()._preprocess(clip), 32)
 
-    def _postprocess_ridge(
-        self, clip: ConstantFormatVideoNode, input_bits: HoldsVideoFormat | VideoFormatLike | int
-    ) -> ConstantFormatVideoNode:
-        return self.depth_scale(super()._postprocess(clip, input_bits), input_bits)
+    def _postprocess_ridge(self, clip: ConstantFormatVideoNode, input_bits: vs.VideoNode) -> ConstantFormatVideoNode:
+        return self._depth_scale(super()._postprocess(clip, input_bits), input_bits)
 
 
 EdgeDetectLike: TypeAlias = type[EdgeDetect] | EdgeDetect | str
