@@ -2,12 +2,18 @@ from __future__ import annotations
 
 from typing import Sequence
 
+from typing_extensions import deprecated
+
 from vsexprtools import norm_expr
-from vstools import PlanesT, fallback, scale_delta, to_arr, vs
+from vstools import Planes, fallback, scale_delta, to_arr, vs
 
 __all__ = ["limit_filter"]
 
 
+@deprecated(
+    "limit_filter is deprecated and will be removed in a future version. Use vszip.LimitFilter instead.",
+    category=DeprecationWarning,
+)
 def limit_filter(
     flt: vs.VideoNode,
     src: vs.VideoNode,
@@ -15,7 +21,7 @@ def limit_filter(
     dark_thr: float | Sequence[float] = 1.0,
     bright_thr: float | Sequence[float] = 1.0,
     elast: float | Sequence[float] = 2.0,
-    planes: PlanesT = None,
+    planes: Planes = None,
 ) -> vs.VideoNode:
     """
     Performs a soft-limiting between two clips to limit the difference of filtering while avoiding artifacts.
@@ -32,6 +38,7 @@ def limit_filter(
     Returns:
         Limited clip.
     """
+
     return norm_expr(
         [flt, src, fallback(ref, src)],
         "x z - dup {bright_thr} {dark_thr} ? THR1! abs DIFF! THR1@ {elast} * THR2! "
