@@ -1,24 +1,25 @@
 from __future__ import annotations
 
 from functools import partial
-from typing import TYPE_CHECKING, Literal, Sequence
+from typing import TYPE_CHECKING, Any, Literal, Sequence
+
+from jetpytools import FuncExcept
 
 from vsexprtools import norm_expr
 from vskernels import Bilinear
 
 if TYPE_CHECKING:
-    from vsmasktools import EdgeDetectLike
+    from vsmasktools import MaskLike
 
 from vstools import (
     ChromaLocation,
     ConstantFormatVideoNode,
     ConvMode,
     FunctionUtil,
-    GenericVSFunction,
     Planes,
     VSFunctionNoArgs,
+    VSFunctionPlanesArgs,
     check_ref_clip,
-    check_variable,
     core,
     get_y,
     join,
@@ -40,26 +41,47 @@ def unsharpen(
     strength: float = 1.0,
     blur: vs.VideoNode | VSFunctionNoArgs[vs.VideoNode, ConstantFormatVideoNode] = partial(gauss_blur, sigma=1.5),
     planes: Planes = None,
+    func: FuncExcept | None = None,
 ) -> ConstantFormatVideoNode:
-    assert check_variable(clip, unsharpen)
+    """
+    Apply an unsharp mask to a clip.
+
+    This filter sharpens the input by subtracting a blurred version of the clip
+    from the original, scaling the difference by the given `strength`, and
+    adding it back to the original image. Conceptually:
+
+        result = clip + (clip - blur(clip)) * strength
+
+    Args:
+        clip: Input clip.
+        strength: Sharpening strength. Defaults to 1.0.
+        blur: Either a blurred reference clip or a callable that takes the source clip
+            and returns a blurred version (e.g., a Gaussian blur).
+        planes: Which planest to process. Default to all.
+        func: func: Function returned for custom error handling. This should only be set by VS package developers.
+
+    Returns:
+        A sharpened clip.
+    """
+    func = func or unsharpen
 
     if callable(blur):
         blur = blur(clip)
 
-    assert check_variable(blur, unsharpen)
-    check_ref_clip(clip, blur, unsharpen)
+    check_ref_clip(clip, blur, func)
 
-    return norm_expr([clip, blur], f"x y - {strength} * x +", planes, func=unsharpen)
+    return norm_expr([clip, blur], f"x y - {strength} * x +", planes, func=func)
 
 
 def awarpsharp(
     clip: vs.VideoNode,
-    mask: EdgeDetectLike | vs.VideoNode | None = None,
+    mask: MaskLike | None = None,
     thresh: int | float = 128,
-    blur: int | GenericVSFunction[vs.VideoNode] | Literal[False] = 3,
+    blur: int | VSFunctionPlanesArgs[vs.VideoNode, vs.VideoNode] | Literal[False] = 3,
     depth: int | Sequence[int] | None = None,
     chroma: bool = False,
     planes: Planes = None,
+    **kwargs: Any,
 ) -> ConstantFormatVideoNode:
     """
     Sharpens edges by warping them.
@@ -80,11 +102,12 @@ def awarpsharp(
             True will create an edge mask from each chroma channel and use those to warp each chroma channel
             individually.
         planes: Planes to process. Defaults to all.
+        **kwargs: Additional arguments forwarded to the [normalize_mask][vsmasktools.normalize_mask] function.
 
     Returns:
         Warp-sharpened clip.
     """
-    from vsmasktools import EdgeDetect, Sobel
+    from vsmasktools import Sobel, normalize_mask
 
     func = FunctionUtil(clip, awarpsharp, planes)
 
@@ -92,16 +115,16 @@ def awarpsharp(
     chroma = True if func.work_clip.format.color_family is vs.RGB else chroma
     mask_planes = planes if chroma else 0
 
-    if not isinstance(mask, vs.VideoNode):
-        mask = EdgeDetect.ensure_obj(mask if mask else Sobel, awarpsharp).edgemask(
-            func.work_clip, clamp=(0, thresh), planes=mask_planes
-        )
+    if mask is None:
+        mask = Sobel
 
-    if isinstance(blur, int):
-        if blur:
-            blur = partial(box_blur, radius=2, passes=blur, planes=planes)
-    else:
-        mask = blur(mask, planes=mask_planes)
+    kwargs = {"clamp": (0, thresh)} | kwargs
+
+    mask = normalize_mask(mask, func.work_clip, func.work_clip, func=func.func, planes=mask_planes, **kwargs)
+
+    if blur is not False:
+        blur_fn = partial(box_blur, radius=2, passes=blur, planes=planes) if isinstance(blur, int) else blur
+        mask = blur_fn(mask, planes=mask_planes)
 
     if not chroma:
         loc = ChromaLocation.from_video(func.work_clip)
