@@ -1,21 +1,18 @@
 from __future__ import annotations
 
 from abc import ABC
-from contextlib import suppress
 from functools import wraps
-from typing import Any, Callable, Sequence, TypeVar
+from typing import Any, Callable, Iterable, TypeVar
 
 from jetpytools import cachedproperty
 
 from vsexprtools import ExprToken, norm_expr
 from vskernels import Bilinear, BorderHandling, Hermite, Kernel, KernelLike, Scaler, ScalerLike
 from vskernels.types import LeftShift, TopShift
-from vsmasktools import KirschTCanny, based_diff_mask, region_rel_mask
-from vsrgtools import BlurMatrix
+from vsmasktools import Kirsch, based_diff_mask, region_rel_mask, stabilize_mask
 from vstools import (
     ColorRange,
     ConstantFormatVideoNode,
-    ConvMode,
     DitherType,
     FieldBased,
     FieldBasedLike,
@@ -28,9 +25,7 @@ from vstools import (
     get_peak_value,
     get_y,
     join,
-    normalize_ranges,
     replace_ranges,
-    scale_mask,
     split,
     vs,
     vs_object,
@@ -82,23 +77,6 @@ class RescaleBase(vs_object, ABC):
 
         self.__add_props = kwargs.get("_add_props")
 
-    def __delattr__(self, name: str) -> None:
-        def _delattr(attr: str) -> None:
-            with suppress(AttributeError):
-                delattr(self, attr)
-
-        match name:
-            case "descale":
-                _delattr("rescale")
-                _delattr("doubled")
-            case "doubled":
-                _delattr("upscale")
-            case _:
-                pass
-
-        with suppress(AttributeError):
-            super().__delattr__(name)
-
     @staticmethod
     def _apply_field_based(
         function: Callable[[_RescaleT, VideoNodeT], VideoNodeT],
@@ -167,35 +145,43 @@ class RescaleBase(vs_object, ABC):
             clip, self._clipy.width, self._clipy.height, **self.descale_args.kwargs(clip)
         )
 
-    @cachedproperty
-    def descale(self) -> ConstantFormatVideoNode:
-        """
-        Gets the descaled clip.
-        """
-        return self._generate_descale(self._clipy)
+    descale = cachedproperty[ConstantFormatVideoNode, vs.VideoNode](
+        lambda self: self._generate_descale(self._clipy),
+        lambda self, value: cachedproperty.update_cache(self, "descale", value),
+        lambda self: cachedproperty.clear_cache(self, ["descale", "rescale", "doubled", "upscale"]),
+    )
+    """
+    Gets the descaled clip.
+    """
 
-    @cachedproperty
-    def rescale(self) -> ConstantFormatVideoNode:
-        """
-        Gets the rescaled clip.
-        """
-        return self._generate_rescale(self.descale)
+    rescale = cachedproperty[ConstantFormatVideoNode, vs.VideoNode](
+        lambda self: self._generate_rescale(self.descale),
+        lambda self, value: cachedproperty.update_cache(self, "rescale", value),
+        lambda self: cachedproperty.clear_cache(self, "rescale"),
+    )
+    """
+    Gets the rescaled clip.
+    """
 
-    @cachedproperty
-    def doubled(self) -> ConstantFormatVideoNode:
-        """
-        Gets the doubled clip.
-        """
-        return self._generate_doubled(self.descale)
+    doubled = cachedproperty[ConstantFormatVideoNode, vs.VideoNode](
+        lambda self: self._generate_doubled(self.descale),
+        lambda self, value: cachedproperty.update_cache(self, "doubled", value),
+        lambda self: cachedproperty.clear_cache(self, ["doubled", "upscale"]),
+    )
+    """
+    Gets the doubled clip.
+    """
 
-    @cachedproperty
-    def upscale(self) -> ConstantFormatVideoNode:
-        """
-        Returns the upscaled clip
-        """
-        return core.std.CopyFrameProps(
-            join(self._generate_upscale(self.doubled), *self._chroma), self._clipy, "_ChromaLocation"
-        )
+    upscale = cachedproperty[ConstantFormatVideoNode, vs.VideoNode](
+        lambda self: core.std.CopyFrameProps(
+            join([self._generate_upscale(self.doubled), *self._chroma]), self._clipy, "_ChromaLocation"
+        ),
+        lambda self, value: cachedproperty.update_cache(self, "upscale", value),
+        lambda self: cachedproperty.clear_cache(self, "upscale"),
+    )
+    """
+    Returns the upscaled clip
+    """
 
     def __vs_del__(self, core_id: int) -> None:
         del self._clipy
@@ -400,8 +386,8 @@ class Rescale(RescaleBase):
             mask = region_rel_mask(
                 pre_y.std.BlankClip(length=1, keep=True),
                 *self._crop,
-                replace_in=ExprToken.RangeMax,
-                replace_out=0,
+                replace_in=0,
+                replace_out=ExprToken.RangeMax,
                 func=self.__class__,
             )
 
@@ -506,7 +492,7 @@ class Rescale(RescaleBase):
 
         clip = clip if clip else self.doubled
 
-        line_mask = KirschTCanny.edgemask(clip, **kwargs).std.Maximum().std.Minimum()
+        line_mask = Kirsch.edgemask(clip, **kwargs).std.Maximum().std.Minimum()
         line_mask = scaler.scale(
             line_mask, self._clipy.width, self._clipy.height, format=self._clipy.format, **scale_kwargs
         )
@@ -522,7 +508,8 @@ class Rescale(RescaleBase):
         thr: float = 0.216,
         expand: int = 4,
         ranges: FrameRangeN | FrameRangesN | None = None,
-        stabilize: bool | tuple[Sequence[float], float] = False,
+        stabilize: bool = True,
+        scenechanges: Iterable[int] | None = None,
         **kwargs: Any,
     ) -> ConstantFormatVideoNode:
         """
@@ -536,6 +523,8 @@ class Rescale(RescaleBase):
             ranges: If specified, ranges to apply the credit clip to.
             stabilize: Try to stabilize the mask by applying a temporal convolution and then binarized by a threshold.
                 Only works when there are ranges specified.
+            scenechanges: Explicit list of scenechange frames for stabilizing the mask.
+            **kwargs: Additional keyword arguments for [based_diff_mask][vsmasktools.based_diff_mask]
 
         Returns:
             Generated mask.
@@ -551,34 +540,7 @@ class Rescale(RescaleBase):
 
         if ranges is not None:
             if stabilize:
-                ranges = normalize_ranges(credit_mask, ranges)
-
-                scprev = [x for s, e in ranges for x in (s, e + int(not replace_ranges.exclusive))]
-                scnext = [x - 1 for x in scprev]
-
-                def set_credit_ranges(n: int, f: vs.VideoFrame) -> vs.VideoFrame:
-                    f = f.copy()
-                    f.props.update(_SceneChangePrev=False, _SceneChangeNext=False)
-
-                    if n in scprev:
-                        f.props["_SceneChangePrev"] = True
-                        return f
-
-                    if n in scnext:
-                        f.props["_SceneChangeNext"] = True
-
-                    return f
-
-                credit_mask = core.std.ModifyFrame(credit_mask, credit_mask, set_credit_ranges)
-
-                if isinstance(stabilize, tuple):
-                    weights, thr = stabilize
-                else:
-                    weights, thr = [1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1], 0.24
-
-                credit_mask = BlurMatrix.custom(weights, ConvMode.T)(credit_mask, scenechange=True).std.BinarizeMask(
-                    scale_mask(thr, 32, credit_mask)
-                )
+                credit_mask = stabilize_mask(credit_mask, 3, ranges, scenechanges, func=self.default_credit_mask)
 
             credit_mask = replace_ranges(credit_mask.std.BlankClip(keep=True), credit_mask, ranges)
 
