@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import Any
 
-from jetpytools import CustomImportError, DependencyNotFoundError, FuncExceptT, SupportsString
+from jetpytools import CustomImportError, DependencyNotFoundError, FuncExcept, SupportsString
 
 __all__ = ["CustomImportError", "DependencyNotFoundError", "OutdatedPluginError"]
 
@@ -14,7 +14,7 @@ class OutdatedPluginError(CustomImportError):
 
     def __init__(
         self,
-        func: FuncExceptT,
+        func: FuncExcept,
         package: str | ImportError,
         message: SupportsString = "Plugin '{package}' version is too old. Please update to a more recent version.",
         **kwargs: Any,
