@@ -1,16 +1,25 @@
 from __future__ import annotations
 
-import string
 from functools import partial, wraps
-from typing import Any, Callable, Iterable, Literal, Mapping, Sequence, Union, overload
+from types import NoneType
+from typing import Callable, Iterable, Mapping, Sequence, SupportsIndex, Union, overload
 from weakref import WeakValueDictionary
 
 import vapoursynth as vs
-from jetpytools import CustomIndexError, CustomStrEnum, CustomValueError, FuncExceptT, P, normalize_seq
+from jetpytools import (
+    CustomIndexError,
+    CustomStrEnum,
+    CustomTypeError,
+    CustomValueError,
+    FuncExcept,
+    P,
+    normalize_seq,
+    to_arr,
+)
 
-from ..enums import ColorRange, ColorRangeT, Matrix
+from ..enums import ColorRange, ColorRangeLike
 from ..exceptions import ClipLengthError, InvalidColorFamilyError
-from ..types import ConstantFormatVideoNode, HoldsVideoFormatT, PlanesT, VideoFormatT
+from ..types import ConstantFormatVideoNode, HoldsVideoFormat, Planes, VideoFormatLike, VideoNodeIterableT
 from .check import check_variable_format
 from .clip import shift_clip
 
@@ -36,7 +45,34 @@ __all__ = [
 ]
 
 
-EXPR_VARS = (alph := list(string.ascii_lowercase))[(idx := alph.index("x")) :] + alph[:idx]
+EXPR_VARS = [
+    "x",
+    "y",
+    "z",
+    "a",
+    "b",
+    "c",
+    "d",
+    "e",
+    "f",
+    "g",
+    "h",
+    "i",
+    "j",
+    "k",
+    "l",
+    "m",
+    "n",
+    "o",
+    "p",
+    "q",
+    "r",
+    "s",
+    "t",
+    "u",
+    "v",
+    "w",
+]
 """
 Variables to access clips in Expr.
 """
@@ -161,11 +197,11 @@ class DitherType(CustomStrEnum):
     @overload
     @staticmethod
     def should_dither(
-        in_fmt: VideoFormatT | HoldsVideoFormatT,
-        out_fmt: VideoFormatT | HoldsVideoFormatT,
+        in_fmt: VideoFormatLike | HoldsVideoFormat,
+        out_fmt: VideoFormatLike | HoldsVideoFormat,
         /,
-        in_range: ColorRangeT | None = None,
-        out_range: ColorRangeT | None = None,
+        in_range: ColorRangeLike | None = None,
+        out_range: ColorRangeLike | None = None,
     ) -> bool:
         """
         Automatically determines whether dithering is needed for a given depth/range/sample type conversion.
@@ -199,8 +235,8 @@ class DitherType(CustomStrEnum):
         in_bits: int,
         out_bits: int,
         /,
-        in_range: ColorRangeT | None = None,
-        out_range: ColorRangeT | None = None,
+        in_range: ColorRangeLike | None = None,
+        out_range: ColorRangeLike | None = None,
         in_sample_type: vs.SampleType | None = None,
         out_sample_type: vs.SampleType | None = None,
     ) -> bool:
@@ -234,11 +270,11 @@ class DitherType(CustomStrEnum):
 
     @staticmethod
     def should_dither(
-        in_bits_or_fmt: int | VideoFormatT | HoldsVideoFormatT,
-        out_bits_or_fmt: int | VideoFormatT | HoldsVideoFormatT,
+        in_bits_or_fmt: int | VideoFormatLike | HoldsVideoFormat,
+        out_bits_or_fmt: int | VideoFormatLike | HoldsVideoFormat,
         /,
-        in_range: ColorRangeT | None = None,
-        out_range: ColorRangeT | None = None,
+        in_range: ColorRangeLike | None = None,
+        out_range: ColorRangeLike | None = None,
         in_sample_type: vs.SampleType | None = None,
         out_sample_type: vs.SampleType | None = None,
     ) -> bool:
@@ -284,12 +320,12 @@ _dither_fmtc_types: dict[DitherType, int] = {
 
 def depth(
     clip: vs.VideoNode,
-    bitdepth: VideoFormatT | HoldsVideoFormatT | int | None = None,
+    bitdepth: VideoFormatLike | HoldsVideoFormat | int | None = None,
     /,
     sample_type: int | vs.SampleType | None = None,
     *,
-    range_in: ColorRangeT | None = None,
-    range_out: ColorRangeT | None = None,
+    range_in: ColorRangeLike | None = None,
+    range_out: ColorRangeLike | None = None,
     dither_type: str | DitherType = DitherType.AUTO,
 ) -> ConstantFormatVideoNode:
     """
@@ -551,278 +587,278 @@ def insert_clip(
 
 
 @overload
-def join(luma: vs.VideoNode, chroma: vs.VideoNode, family: vs.ColorFamily | None = None) -> ConstantFormatVideoNode:
+def join(
+    luma: vs.VideoNode, chroma: vs.VideoNode, /, *, prop_src: vs.VideoNode | SupportsIndex | None = ...
+) -> ConstantFormatVideoNode:
     """
-    Join a list of planes together to form a single YUV clip.
+    Combine a luma and chroma clip into a YUV clip.
 
     Args:
-        luma: Luma clip, GRAY or YUV.
-        chroma: Chroma clip, must be YUV.
+        luma: Luma clip (GRAY or YUV).
+        chroma: Chroma clip (must be YUV).
+        prop_src: Clip or index to copy frame properties from.
 
     Returns:
-        YUV clip of combined planes.
+        YUV clip with combined planes.
     """
 
 
 @overload
 def join(
-    y: vs.VideoNode, u: vs.VideoNode, v: vs.VideoNode, family: Literal[vs.ColorFamily.YUV]
+    plane0: vs.VideoNode,
+    plane1: vs.VideoNode,
+    plane2: vs.VideoNode,
+    alpha: vs.VideoNode | None = None,
+    /,
+    *,
+    family: vs.ColorFamily = vs.ColorFamily.YUV,
+    prop_src: vs.VideoNode | SupportsIndex | None = ...,
 ) -> ConstantFormatVideoNode:
     """
-    Join a list of planes together to form a single YUV clip.
+    Combine three single-plane clips into one, with optional alpha.
 
     Args:
-        y: Y plane.
-        u: U plane.
-        v: V plane.
+        plane0: First plane.
+        plane1: Second plane.
+        plane2: Third plane.
+        alpha: Optional alpha clip.
+        family: Output color family. Defaults to YUV.
+        prop_src: Clip or index to copy frame properties from.
 
     Returns:
-        YUV clip of combined planes.
+        Clip with combined planes.
     """
 
 
 @overload
 def join(
-    y: vs.VideoNode, u: vs.VideoNode, v: vs.VideoNode, alpha: vs.VideoNode, family: Literal[vs.ColorFamily.YUV]
+    planes: Sequence[vs.VideoNode],
+    family: vs.ColorFamily = vs.ColorFamily.YUV,
+    /,
+    *,
+    prop_src: vs.VideoNode | SupportsIndex | None = ...,
 ) -> ConstantFormatVideoNode:
     """
-    Join a list of planes together to form a single YUV clip.
+    Combine a sequence of single-plane clips into one.
 
     Args:
-        y: Y plane.
-        u: U plane.
-        v: V plane.
-        alpha: Alpha clip.
+        planes: Planes to merge.
+        family: Output color family. Defaults to YUV.
+        prop_src: Optional clip or index to copy frame properties from.
 
     Returns:
-        YUV clip of combined planes with an alpha clip attached.
+        Clip with combined planes.
     """
 
 
 @overload
 def join(
-    r: vs.VideoNode, g: vs.VideoNode, b: vs.VideoNode, family: Literal[vs.ColorFamily.RGB]
+    clips: Mapping[Planes, vs.VideoNode | None],
+    family: vs.ColorFamily = vs.ColorFamily.YUV,
+    /,
+    *,
+    prop_src: vs.VideoNode | SupportsIndex | None = ...,
 ) -> ConstantFormatVideoNode:
     """
-    Join a list of planes together to form a single RGB clip.
+    Combine a sequence of single-plane clips into one.
 
     Args:
-        r: R plane.
-        g: G plane.
-        b: B plane.
+        planes: Planes to merge.
+        family: Output color family. Defaults to YUV.
+        prop_src: Optional clip or index to copy frame properties from.
 
     Returns:
-        RGB clip of combined planes.
+        Clip with combined planes.
     """
 
 
-@overload
 def join(
-    r: vs.VideoNode, g: vs.VideoNode, b: vs.VideoNode, alpha: vs.VideoNode, family: Literal[vs.ColorFamily.RGB]
-) -> ConstantFormatVideoNode:
+    clips: vs.VideoNode | Sequence[vs.VideoNode] | Mapping[Planes, vs.VideoNode | None],
+    plane1_or_family: vs.VideoNode | vs.ColorFamily | None = None,
+    plane2: vs.VideoNode | None = None,
+    alpha: vs.VideoNode | None = None,
+    /,
+    *,
+    family: vs.ColorFamily = vs.ColorFamily.YUV,
+    prop_src: vs.VideoNode | SupportsIndex | None = None,
+) -> vs.VideoNode:
     """
-    Join a list of planes together to form a single RGB clip.
+    General interface to combine clips or planes into a single clip.
 
     Args:
-        r: R plane.
-        g: G plane.
-        b: B plane.
-        alpha: Alpha clip.
+        clips: First plane, sequence of single-plane clips or mapping of planes to clips:
+        plane1_or_family: Chroma clip, second plane or color family, depending on usage.
+        plane2: Third plane when combining three planes.
+        alpha: Optional alpha clip.
+        family: Output color family. Defaults to YUV.
+        prop_src: Optional clip or index to copy frame properties from.
+
+    Raises:
+        CustomIndexError: Invalid plane index.
+        CustomTypeError: Invalid input type.
 
     Returns:
-        RGB clip of combined planes with an alpha clip attached.
+        Clip with combined planes.
     """
+    if isinstance(clips, Mapping):
+        from ..functions import flatten_vnodes
 
+        clips_map = dict[int, vs.VideoNode]()
 
-@overload
-def join(*planes: vs.VideoNode, family: vs.ColorFamily | None = None) -> ConstantFormatVideoNode:
-    """
-    Join a list of planes together to form a single clip.
-
-    Args:
-        *planes: Planes to combine.
-        family: Output clip family. Default: first clip or detected from props if GRAY and len(planes) > 1.
-
-    Returns:
-        Clip of combined planes.
-    """
-
-
-@overload
-def join(planes: Iterable[vs.VideoNode], family: vs.ColorFamily | None = None) -> ConstantFormatVideoNode:
-    """
-    Join a list of planes together to form a single clip.
-
-    Args:
-        planes: Planes to combine.
-        family: Output clip family. Default: first clip or detected from props if GRAY and len(planes) > 1.
-
-    Returns:
-        Clip of combined planes.
-    """
-
-
-@overload
-def join(
-    planes: Mapping[PlanesT, vs.VideoNode | None], family: vs.ColorFamily | None = None
-) -> ConstantFormatVideoNode:
-    """
-    Join a map of planes together to form a single clip.
-
-    Args:
-        planes: Planes to combine.
-        family: Output clip family. Default: first clip or detected from props if GRAY and len(planes) > 1.
-
-    Returns:
-        Clip of combined planes.
-    """
-
-
-def join(*_planes: Any, **kwargs: Any) -> vs.VideoNode:
-    """
-    Join a list of planes together to form a single clip.
-
-    Args:
-        _planes: Planes to combine.
-
-    Returns:
-        Combined planes.
-    """
-
-    from ..functions import flatten_vnodes, to_arr
-    from ..utils import get_color_family, get_video_format
-
-    family: vs.ColorFamily | None = kwargs.get("family")
-
-    if isinstance(_planes[-1], vs.ColorFamily):
-        family = _planes[-1]
-        _planes = _planes[:-1]
-
-    if isinstance(_planes[0], Mapping):
-        planes_map = dict[int, vs.VideoNode]()
-
-        for p_key, node in _planes[0].items():
+        for p_key, node in clips.items():
             if node is None:
                 continue
 
             if p_key is None:
-                planes_map |= dict(enumerate(flatten_vnodes(node, split_planes=True)))
+                clips_map.update(enumerate(flatten_vnodes(node, split_planes=True)))
             else:
-                planes_map |= {i: plane(node, min(i, node.format.num_planes - 1)) for i in to_arr(p_key)}
+                clips_map.update((i, plane(node, i)) for i in to_arr(p_key))
 
-        return join(*(planes_map[i] for i in sorted(planes_map.keys())))
+        return join([clips_map[i] for i in sorted(clips_map)], family, prop_src=prop_src)
 
-    planes = list[vs.VideoNode](
-        _planes[0] if (isinstance(_planes[0], Iterable) and not isinstance(_planes[0], vs.VideoNode)) else _planes
-    )
+    if not isinstance(clips, vs.VideoNode):
+        if isinstance(plane1_or_family, vs.ColorFamily):
+            family = plane1_or_family
 
-    n_clips = len(planes)
+        if (n_clips := len(clips)) == 1:
+            return clips[0]
+        if n_clips in (2, 3, 4):
+            return join(*clips, family=family, prop_src=prop_src)
+        else:
+            raise CustomIndexError("Too many or not enough clips/planes passed!", join, n_clips)
 
-    if not n_clips:
-        raise CustomIndexError("Not enough clips/planes passed!", join)
+    if not isinstance(plane1_or_family, vs.VideoNode):
+        raise CustomTypeError(func=join)
 
-    if n_clips == 1 and (family is None or family is (planes[0].format and planes[0].format.color_family)):
-        return planes[0]
+    if not plane2:
+        InvalidColorFamilyError.check(
+            (family, plane1_or_family),
+            vs.YUV,
+            join,
+            "When combining two clips, color family and chroma clip must be {correct}, not {wrong}.",
+        )
 
-    if family is None:
-        family = get_color_family(planes[0])
+        clips = [clips, plane1_or_family]
+        planes = [0, 1, 2]
 
-    if n_clips == 2:
-        other_family = get_color_family(planes[1])
+    else:
+        clips = [clips, plane1_or_family, plane2]
+        planes = [0, 0, 0]
 
-        if family in {vs.GRAY, vs.YUV}:
-            InvalidColorFamilyError.check(
-                other_family, vs.YUV, join, '"chroma" clip must be {correct} color family, not {wrong}!'
-            )
+    if not isinstance(prop_src, (vs.VideoNode, NoneType)):
+        prop_src = clips[prop_src.__index__()]
 
-            if family is vs.GRAY:
-                planes[0] = get_y(planes[0])
+    joined = vs.core.std.ShufflePlanes(clips, planes, family, prop_src)
 
-            return vs.core.std.ShufflePlanes(planes, [0, 1, 2], other_family)
+    if alpha:
+        joined = joined.std.ClipToProp(alpha, "_Alpha")
 
-    if n_clips in {3, 4}:
-        if family is vs.GRAY:
-            for pplane in planes[:3]:
-                if (fmt := get_video_format(pplane)).num_planes > 1:
-                    family = fmt.color_family
-                    break
-            else:
-                matrix = Matrix.from_video(planes[0])
-                family = vs.RGB if matrix is Matrix.RGB else vs.YUV
-
-        clip = vs.core.std.ShufflePlanes(planes[:3], [0, 0, 0], family)
-
-        if n_clips == 4:
-            clip = clip.std.ClipToProp(planes[-1], "_Alpha")
-
-        return clip
-    elif n_clips > 4:
-        raise CustomValueError("Too many clips or planes passed!", join)
-
-    raise CustomValueError("Not enough clips or planes passed!", join)
+    return joined
 
 
-def plane(clip: vs.VideoNode, index: int, /, strict: bool = True) -> ConstantFormatVideoNode:
+def plane(clip: vs.VideoNode, index: SupportsIndex, /, strict: bool = True) -> ConstantFormatVideoNode:
     """
     Extract a plane from the given clip.
 
     Args:
         clip: Input clip.
         index: Index of the plane to extract.
+        strict: If False, removes `_Matrix` property when the input clip is RGB.
 
     Returns:
         Grayscale clip of the clip's plane.
     """
-
     assert check_variable_format(clip, plane)
 
-    if clip.format.num_planes == 1 and index == 0:
+    if clip.format.num_planes == 1 and index.__index__() == 0:
         return clip
 
     if not strict and clip.format.color_family is vs.RGB:
         clip = vs.core.std.RemoveFrameProps(clip, "_Matrix")
 
-    return vs.core.std.ShufflePlanes(clip, index, vs.GRAY)
+    return vs.core.std.ShufflePlanes(clip, index.__index__(), vs.GRAY)
 
 
-def split(clip: vs.VideoNode, /) -> list[ConstantFormatVideoNode]:
+def split(clip: vs.VideoNode, /, strict: bool = True) -> list[ConstantFormatVideoNode]:
     """
     Split a clip into a list of individual planes.
 
     Args:
         clip: Input clip.
+        strict: If False, removes `_Matrix` property when the input clip is RGB.
 
     Returns:
         List of individual planes.
     """
-
     assert check_variable_format(clip, split)
 
-    return [clip] if clip.format.num_planes == 1 else [plane(clip, i, False) for i in range(clip.format.num_planes)]
+    return [clip] if clip.format.num_planes == 1 else [plane(clip, i, strict) for i in range(clip.format.num_planes)]
 
 
 depth_func = depth
 
 
-def stack_clips(
-    clips: Sequence[
-        vs.VideoNode
-        | Sequence[
-            vs.VideoNode
-            | Sequence[vs.VideoNode | Sequence[vs.VideoNode | Sequence[vs.VideoNode | Sequence[vs.VideoNode]]]]
-        ]
-    ],
-) -> vs.VideoNode:
+def stack_clips(clips: Iterable[VideoNodeIterableT[vs.VideoNode]]) -> vs.VideoNode:
     """
-    Stack clips in the following repeating order: hor->ver->hor->ver->...
+    Recursively stack clips in alternating directions: horizontal → vertical → horizontal → ...
+
+    This function takes a nested sequence of clips (or lists of clips) and stacks them
+    alternately along the horizontal and vertical axes at each nesting level.
+
+    Examples:
+        - Stack a list of clips horizontally:
+          ```py
+          from vstools import core, split, vs
+
+          clip = core.std.BlankClip(format=vs.RGB24)
+          clips = split(clip)
+
+          stacked = stack_clips(clips)
+          ```
+
+        - Stack a list of clips vertically (wrap in another list):
+          ```py
+          from vstools import core, split, vs
+
+          clip = core.std.BlankClip(format=vs.RGB24)
+          clips = split(clip)
+
+          stacked = stack_clips([clips])
+          ```
+
+        - Stack the Y plane horizontally with the U and V planes stacked vertically:
+          ```py
+          from vstools import core, split, vs
+
+          clip = core.std.BlankClip(format=vs.YUV420P8)
+          y, u, v = split(clip)
+
+          stacked = stack_clips([y, [u, v]])
+          ```
+
+        - Stack multiple YUV clips, with Y planes horizontally and UV planes vertically:
+          ```py
+          from vstools import core, split, vs
+
+          yuv_clips = [...]  # all must share format and height
+
+          clips = []
+          for yuv_clip in yuv_clips:
+              y, *uv = split(yuv_clip)
+              clips.extend([y, uv])
+
+          stacked = stack_clips(clips)
+          ```
+
+        - Using ``append`` instead of ``extend`` (and wrapping the sequence, e.g. ``stack_clips([clips])``)
+          changes the stacking layout, since it alters the nesting depth.
 
     Args:
-        clips: Sequence of clips to stack recursively.
+        clips: A (possibly nested) sequence of clips to be stacked.
 
     Returns:
         Stacked clips.
     """
-
     return vs.core.std.StackHorizontal(
         [
             inner_clips
@@ -845,8 +881,9 @@ def limiter(
     max_val: float | Sequence[float] | None = None,
     *,
     tv_range: bool = False,
-    planes: PlanesT = None,
-    func: FuncExceptT | None = None,
+    mask: bool = False,
+    planes: Planes = None,
+    func: FuncExcept | None = None,
 ) -> ConstantFormatVideoNode:
     """
     Wraps `vs-zip <https://github.com/dnjulek/vapoursynth-zip>`.Limiter but only processes
@@ -859,6 +896,7 @@ def limiter(
         max_val: Upper bound. Defaults to the highest allowed value for the input. Can be specified for each plane
             individually.
         tv_range: Changes min/max defaults values to LIMITED.
+        mask: Float chroma range from -0.5/0.5 to 0.0/1.0.
         planes: Planes to process.
         func: Function returned for custom error handling. This should only be set by VS package developers.
 
@@ -875,8 +913,9 @@ def limiter(
     max_val: float | Sequence[float] | None = None,
     *,
     tv_range: bool = False,
-    planes: PlanesT = None,
-    func: FuncExceptT | None = None,
+    mask: bool = False,
+    planes: Planes = None,
+    func: FuncExcept | None = None,
 ) -> Callable[P, ConstantFormatVideoNode]:
     """
     Wraps `vs-zip <https://github.com/dnjulek/vapoursynth-zip>`.Limiter but only processes
@@ -891,6 +930,7 @@ def limiter(
         max_val: Upper bound. Defaults to the highest allowed value for the input. Can be specified for each plane
             individually.
         tv_range: Changes min/max defaults values to LIMITED.
+        mask: Float chroma range from -0.5/0.5 to 0.0/1.0.
         planes: Planes to process.
         func: Function returned for custom error handling. This should only be set by VS package developers.
 
@@ -905,8 +945,9 @@ def limiter(
     min_val: float | Sequence[float] | None = None,
     max_val: float | Sequence[float] | None = None,
     tv_range: bool = False,
-    planes: PlanesT = None,
-    func: FuncExceptT | None = None,
+    mask: bool = False,
+    planes: Planes = None,
+    func: FuncExcept | None = None,
 ) -> Callable[[Callable[P, ConstantFormatVideoNode]], Callable[P, ConstantFormatVideoNode]]:
     """
     Wraps `vs-zip <https://github.com/dnjulek/vapoursynth-zip>`.Limiter but only processes
@@ -920,6 +961,7 @@ def limiter(
         max_val: Upper bound. Defaults to the highest allowed value for the input. Can be specified for each plane
             individually.
         tv_range: Changes min/max defaults values to LIMITED.
+        mask: Float chroma range from -0.5/0.5 to 0.0/1.0.
         planes: Planes to process.
         func: Function returned for custom error handling. This should only be set by VS package developers.
 
@@ -935,8 +977,9 @@ def limiter(
     max_val: float | Sequence[float] | None = None,
     *,
     tv_range: bool = False,
-    planes: PlanesT = None,
-    func: FuncExceptT | None = None,
+    mask: bool = False,
+    planes: Planes = None,
+    func: FuncExcept | None = None,
 ) -> Union[
     ConstantFormatVideoNode,
     Callable[P, ConstantFormatVideoNode],
@@ -953,6 +996,7 @@ def limiter(
         max_val: Upper bound. Defaults to the highest allowed value for the input. Can be specified for each plane
             individually.
         tv_range: Changes min/max defaults values to LIMITED.
+        mask: Float chroma range from -0.5/0.5 to 0.0/1.0.
         planes: Planes to process.
         func: Function returned for custom error handling. This should only be set by VS package developers.
 
@@ -965,7 +1009,13 @@ def limiter(
         @wraps(_func)
         def _wrapper(*args: P.args, **kwargs: P.kwargs) -> ConstantFormatVideoNode:
             return limiter(
-                _func(*args, **kwargs), min_val, max_val, tv_range=tv_range, planes=planes, func=func or _func
+                _func(*args, **kwargs),
+                min_val,
+                max_val,
+                tv_range=tv_range,
+                mask=mask,
+                planes=planes,
+                func=func or _func,
             )
 
         return _wrapper
@@ -987,7 +1037,7 @@ def limiter(
         min_val = normalize_seq(min_val or get_lowest_values(clip, clip), clip.format.num_planes)
         max_val = normalize_seq(max_val or get_peak_values(clip, clip), clip.format.num_planes)
 
-    return clip.vszip.Limiter(min_val, max_val, tv_range, planes)
+    return clip.vszip.Limiter(min_val, max_val, tv_range, mask, planes)
 
 
 def sc_detect(clip: vs.VideoNode, threshold: float = 0.1) -> ConstantFormatVideoNode:
