@@ -1,17 +1,17 @@
 from __future__ import annotations
 
-import builtins
-import gc
-import weakref
 from ctypes import Structure
-from inspect import Parameter, Signature
+from gc import get_referents, get_referrers
+from inspect import Parameter, Signature, stack
 from logging import NOTSET as LOGLEVEL_NOTSET
 from logging import Handler, LogRecord
-from math import ceil
-from multiprocessing import cpu_count
-from types import UnionType
+from pathlib import Path
+from sys import modules
+from sys import path as sys_path
+from types import ModuleType
 from typing import TYPE_CHECKING, Any, Callable, Iterable, NoReturn
 from weakref import ReferenceType
+from weakref import ref as weakref_ref
 
 import vapoursynth as vs
 from vapoursynth import (
@@ -379,7 +379,6 @@ from .vs_enums import (
     YUV444PH,
     YUV444PS,
     PresetVideoFormat,
-    VSPresetVideoFormat,
 )
 
 __all__ = [
@@ -763,31 +762,20 @@ __all__ = [
 ]
 
 
-if not TYPE_CHECKING:
-    import inspect
-    import re
-    import sys
-    import warnings
-    from pathlib import Path
-    from types import ModuleType
+import __main__
 
-    import __main__
+if not hasattr(__main__, "__file__") and "__vapoursynth__" not in modules:
+    first_stack = stack()[-1]
 
-    if not hasattr(__main__, "__file__") and "__vapoursynth__" not in sys.modules:
-        first_stack = inspect.stack()[-1]
+    modules["__vapoursynth__"] = ModuleType("__vapoursynth__")
 
-        sys.modules["__vapoursynth__"] = ModuleType("__vapoursynth__")
+    cope = (Path.cwd() / first_stack.filename).resolve()
 
-        cope = (Path.cwd() / first_stack.filename).resolve()
+    first_stack = None
 
-        first_stack = None
+    modules["__vapoursynth__"].__file__ = __main__.__file__ = str(cope)
 
-        sys.modules["__vapoursynth__"].__file__ = __main__.__file__ = str(cope)
-
-        sys.path.append(str(cope.parent))
-
-    warnings._add_filter("ignore", re.compile(".*smallest subnormal.*numpy.*"), Warning, None, 0, append=False)
-    warnings._add_filter("ignore", re.compile(".*divide by zero.*"), Warning, None, 0, append=False)
+    sys_path.append(str(cope.parent))
 
 
 def register_on_creation(callback: Callable[..., None], strict: bool = False) -> None:
@@ -795,7 +783,7 @@ def register_on_creation(callback: Callable[..., None], strict: bool = False) ->
     Register a callback on every core creation.
     """
 
-    core_on_creation_callbacks.update({id(callback): weakref.ref(callback)})
+    core_on_creation_callbacks.update({id(callback): weakref_ref(callback)})
 
     if not strict and core.active:
         try:
@@ -882,7 +870,7 @@ class PluginProxy(PluginProxyBase):
 class CoreProxy(CoreProxyBase):
     def __init__(self, core: Core | None, vs_proxy: VSCoreProxy, lazy: bool) -> None:
         self.lazy = lazy
-        self.__dict__["vs_core_ref"] = (core and weakref.ref(core), vs_proxy)
+        self.__dict__["vs_core_ref"] = (core and weakref_ref(core), vs_proxy)
 
     def __getattr__(self, name: str) -> Plugin:
         if self.lazy and name not in vs.Core.__dict__:
@@ -908,7 +896,7 @@ class proxy_utils:  # noqa: N801
                 raise CustomRuntimeError("The VapourSynth core has been freed!", CoreProxy)
 
             vs_core = _get_core(vs_proxy)
-            core.__dict__["vs_core_ref"] = (vs_core and weakref.ref(vs_core), vs_proxy)
+            core.__dict__["vs_core_ref"] = (vs_core and weakref_ref(vs_core), vs_proxy)
 
         return vs_core or _get_core_with_cb()
 
@@ -929,23 +917,6 @@ class proxy_utils:  # noqa: N801
         return plugin.__dict__["plugin_ref"]
 
 
-def vstools_isinstance(
-    obj: object, class_or_tuple: type | UnionType | tuple[type | UnionType | tuple[Any, ...], ...], /
-) -> bool:
-    if class_or_tuple in (_CoreProxy, Core) and builtins_isinstance(obj, CoreProxy):
-        return True
-
-    if class_or_tuple is VSPresetVideoFormat and builtins_isinstance(obj, PresetVideoFormat):
-        return True
-
-    return builtins_isinstance(obj, class_or_tuple)
-
-
-if builtins.isinstance is not vstools_isinstance:
-    builtins_isinstance = builtins.isinstance
-    builtins.isinstance = vstools_isinstance
-
-
 def _get_core(self: VSCoreProxy) -> Core | None:
     core_ref: ReferenceType[Core] | None = object.__getattribute__(self, "_core")
     own_core: bool = object.__getattribute__(self, "_own_core")
@@ -960,7 +931,7 @@ def _get_core(self: VSCoreProxy) -> Core | None:
 
 
 if TYPE_CHECKING:
-    core_on_creation_callbacks = dict[int, weakref.ReferenceType[Callable[..., None]]]()
+    core_on_creation_callbacks = dict[int, ReferenceType[Callable[..., None]]]()
 else:
     core_on_creation_callbacks = {}
 
@@ -995,7 +966,7 @@ def _find_ref(start_data: Any, to_return: type | tuple[type, ...], it: int = 3)
     if not it:
         return None
 
-    for objects in [gc.get_referents(start_data), gc.get_referrers(start_data)]:
+    for objects in [get_referents(start_data), get_referrers(start_data)]:
         for obj in objects:
             if isinstance(obj, to_return):
                 return obj
@@ -1003,10 +974,10 @@ def _find_ref(start_data: Any, to_return: type | tuple[type, ...], it: int = 3)
             if isinstance(obj, dict) and "__name__" in obj:
                 continue
 
-            if isinstance(obj, (Core, _CoreProxy, _FastManager)):
+            if isinstance(obj, (Core, _CoreProxy, CoreProxy, _FastManager)):
                 continue
 
-            for obj_obj in gc.get_referents(obj):
+            for obj_obj in get_referents(obj):
                 if isinstance(obj_obj, to_return):
                     return obj_obj
 
@@ -1045,7 +1016,7 @@ class EnvironmentProxy(EnvironmentProxyBase):
 
     @property
     def has_core(self) -> bool:
-        return any(isinstance(ref, Core) for ref in gc.get_referents(self.data))
+        return any(isinstance(ref, (Core, CoreProxy)) for ref in get_referents(self.data))
 
 
 _curr_env_proxy = EnvironmentProxy()
@@ -1058,7 +1029,7 @@ class VSCoreProxy(CoreProxyBase):
 
     def __init__(self, core: Core | None = None) -> None:
         object.__setattr__(self, "_own_core", core is not None)
-        object.__setattr__(self, "_core", core and weakref.ref(core))
+        object.__setattr__(self, "_core", core and weakref_ref(core))
 
     def __getattr__(self, name: str) -> Plugin:
         return getattr(_get_core_with_cb(self), name)
@@ -1143,26 +1114,47 @@ class VSCoreProxy(CoreProxyBase):
         self,
         threads: int | float | range | tuple[int, int] | list[int] | None = None,
         max_cache: int | None = None,
-        reserve: int | Iterable[int] = 2,
+        reserve: Iterable[int] = [],
     ) -> None:
+        """
+        Configure CPU core affinity and cache settings for VapourSynth.
+
+        This function selects which CPU cores the current process is allowed to run on,
+        and configures the number of worker threads used by VapourSynth. It also allows
+        tuning of the frame buffer cache.
+
+        Args:
+            threads: Defines how many and which CPU cores to use.
+
+                Accepted formats:
+
+                   - ``None``: Use all available CPU cores.
+                   - ``int``: Use cores ``0`` through ``threads - 1``.
+                   - ``float``: A fraction of available cores (e.g., ``0.5`` = half the cores).
+                   - ``range``: Use the specified range of cores.
+                   - ``tuple[int, int]``: Equivalent to ``range(start, stop)``.
+                   - ``list[int]``: Explicit list of core indices.
+
+            max_cache: Maximum VapourSynth frame buffer cache size, in megabytes.
+                If ``None``, the default setting is preserved.
+
+        Raises:
+            CustomValueError: If ``threads`` is lower than or equal to 0.
+        """
+        from math import ceil
+        from multiprocessing import cpu_count
+
+        from jetpytools import CustomValueError
         from psutil import Process
 
-        """
-        Set core affinity.
-
-        :param threads:     How many and which threads to use for VapourSynth.
-        :param max_cache:   Maximum cache used for frame data in VapourSynth.
-        :param reserve:     Reserve n amount of or the specified threads.
-
-        :raises DependencyNotFoundError:    Psutil was not found.
-        """
-
         if threads is None:
             threads = cpu_count()
 
         if isinstance(threads, float):
-            if threads >= 0.0 or threads >= 1.0:
-                threads = 1.0
+            if threads <= 0:
+                raise CustomValueError(
+                    "When passing a float, `threads` should be greater than 0.", self.set_affinity, threads
+                )
 
             threads = ceil(cpu_count() * threads)
 
@@ -1171,13 +1163,7 @@ class VSCoreProxy(CoreProxyBase):
         elif isinstance(threads, tuple):
             threads = range(*threads)
 
-        threads = list(set(threads))
-
-        if isinstance(reserve, int):
-            if reserve > len(threads):
-                threads = threads[:-reserve]
-        else:
-            threads = [t for t in threads if t not in reserve]
+        threads = list(set(threads) - set(reserve))
 
         self.core.num_threads = len(threads)
 
@@ -1215,7 +1201,7 @@ if TYPE_CHECKING:
 
         def _on_log_message(self, level: MessageType, msg: str) -> None: ...
 
-        def on_policy_registered(self, api: "EnvironmentPolicyAPI") -> None: ...
+        def on_policy_registered(self, api: EnvironmentPolicyAPI) -> None: ...  # pyright: ignore[reportIncompatibleMethodOverride]
 
         def on_policy_cleared(self) -> None: ...
 
@@ -1228,7 +1214,7 @@ if TYPE_CHECKING:
     class VSScriptEnvironmentPolicy(EnvironmentPolicy):
         def __init__(self) -> NoReturn: ...
 
-        def on_policy_registered(self, policy_api: "EnvironmentPolicyAPI") -> None: ...
+        def on_policy_registered(self, policy_api: EnvironmentPolicyAPI) -> None: ...  # pyright: ignore[reportIncompatibleMethodOverride]
 
         def on_policy_cleared(self) -> None: ...
 
